SPM12
=====

|Version| |Py-Versions| |Tests| |Coverage| |DOI| |LICENCE|

Thin Python wrappers around `Statistical Parametric Mapping <https://www.fil.ion.ucl.ac.uk/spm>`_.

|PET-MR Coregistration|


Install
-------

Currently requires MATLAB. May change in future.

.. code:: sh

    python -m pip install -U spm12
    python -m spm12


Examples
--------

See `examples/demo.ipynb <https://github.com/AMYPAD/SPM12/blob/master/examples/demo.ipynb>`_.


Contributing
------------

See `CONTRIBUTING.md <https://github.com/AMYPAD/SPM12/blob/master/CONTRIBUTING.md>`_.


.. |PET-MR Coregistration| image:: https://raw.githubusercontent.com/AMYPAD/images/master/spm12/pet_mr_coreg.png
.. |Tests| image:: https://img.shields.io/github/workflow/status/AMYPAD/SPM12/Test?logo=GitHub
   :target: https://github.com/AMYPAD/SPM12/actions
.. |Coverage| image:: https://codecov.io/gh/AMYPAD/SPM12/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/AMYPAD/SPM12
.. |Version| image:: https://img.shields.io/pypi/v/spm12.svg?logo=python&logoColor=white
   :target: https://github.com/AMYPAD/SPM12/releases
.. |Py-Versions| image:: https://img.shields.io/pypi/pyversions/spm12.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/spm12
.. |DOI| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4272003.svg
   :target: https://doi.org/10.5281/zenodo.4272003
.. |LICENCE| image:: https://img.shields.io/pypi/l/spm12.svg
   :target: https://raw.githubusercontent.com/AMYPAD/spm12/master/LICENCE.md
